#
# spec file for package rosegarden
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           rosegarden
Version:        16.06
Release:        3.17
License:        GPL-2.0+
Summary:        Midi, Audio And Notation Editor
Url:            http://www.rosegardenmusic.com/
Group:          Productivity/Multimedia/Sound/Midi
# http://sourceforge.net/projects/rosegarden/files/ This source url prevents me from checking out the tarball.
Source0:        %{name}/%{version}/%{name}-%{version}.tar.bz2
Source1:        %{name}.xpm
Source2:        %{name}.1
# PATCH-FIX-OPENSUSE davejplater@gmail.com This patch fixes the file search paths for examples, templates and midi driver libraries.
Patch1:         rosegarden-10.10-filepaths.patch
# PATCH-FIX-OPENSUSE ledest@gmail.com fix bashisms in scripts
Patch2:         rosegarden-14.02-fix-bashisms.patch
#PATCH_FIX-UPSTREAM davejplater@gmail.com Fixes https://sourceforge.net/p/rosegarden/bugs/1536/
Patch3:         rosegarden-fix-crash.patch
BuildRequires:  alsa-devel
BuildRequires:  cmake >= 2.8.12
BuildRequires:  dssi-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa-devel
BuildRequires:  libjack-devel
BuildRequires:  liblo-devel
BuildRequires:  liblrdf-devel
%if 0%{?suse_version} > 1320 || 0%{?is_opensuse} == 1
BuildRequires: pkgconfig(Qt5Core)
BuildRequires: pkgconfig(Qt5Gui)
BuildRequires: pkgconfig(Qt5Network)
BuildRequires: pkgconfig(Qt5PrintSupport)
BuildRequires: pkgconfig(Qt5Widgets)
BuildRequires: pkgconfig(Qt5Xml)
BuildRequires: pkgconfig(Qt5Test)
BuildRequires: cmake(Qt5LinguistTools)
%else
BuildRequires:  libqt4-devel >= 4.6.3
%endif
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  lilypond
BuildRequires:  lirc-devel
BuildRequires:  pkg-config
#BuildRequires:  pkgconfig(libxml++-2.6)
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-util-devel
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       dssi
Requires:       xsynth-dssi
Requires:       ladspa
Requires:       ladspa-swh-plugins
Requires:       lilypond
Requires:       jack
Recommends:     qsynth
Recommends:     fluidsynth-dssi
# This is old, rosegarden was a kde3 app called rosegarden4 and it's first qt4 version had the qt4 suffix.
#Provides:       rosegarden-qt4 = %%{version}
#Obsoletes:      rosegarden-qt4 < %%{version}
#Provides:       rosegarden4 = %%{version}
#Obsoletes:      rosegarden4 < %%{version}
Icon:           rosegarden.xpm
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Rosegarden is a well-rounded audio and MIDI sequencer,
score editor, and general-purpose music composition and
editing environment. Rosegarden is an easy-to-learn,
attractive application that runs on Linux, ideal for
composers, musicians, music students, and small studio or
home recording environments.
This is a complete rewrite of the old 1.7.x series of
rosegarden and has many new features and enhancements.
See the changelog for details.

%prep
%setup -q
%patch1
%patch2
%patch3 -p1
# When we build svn we need to execute bootstrap.sh
#sh bootstrap.sh

%build
#export DEBUG_LADSPA
#export QTDIR=/usr/
export CFLAGS="%{optflags} -fno-strict-aliasing -ggdb"
export CXXFLAGS="$CFLAGS"
# -fmessage-length=0 -O2 -fno-strict-aliasing -Wall -D_FORTIFY_SOURCE=2 -fstack-protector -funwind-tables -fasynchronous-unwind-tables
# Now uses cmake
#%%configure --enable-debug --localedir=%%{_datadir}/%%{name}/locale/
%cmake \
%if 0%{?suse_version} > 1320 || 0%{?is_opensuse} == 1
       -DUSE_QT5:BOOL=ON \
%endif
       -DCMAKE_INSTALL_LOCALEDIR:PATH=%{_datadir}/locale/

make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_datadir}/%{name}/scripts
cp -p scripts/* %{buildroot}%{_datadir}/%{name}/scripts/
cp -r data/* %{buildroot}%{_datadir}/%{name}/

pushd build
%make_install
popd
rm -rf %{buildroot}%{_datadir}/%{name}/desktop
rm -rf %{buildroot}%{_datadir}/%{name}/mime
rm -f %{buildroot}%{_datadir}/%{name}/*.cpp
rm -f %{buildroot}%{_datadir}/%{name}/*.o
chmod 755 %{buildroot}%{_datadir}/%{name}/scripts/*
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/lircrc.rosegarden
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/README
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/color-list
#chmod 644 %%{buildroot}%%{_datadir}/%%{name}/scripts/simple-makefile
rm -f %{buildroot}%{_datadir}/%{name}/scripts/svn-to-hg-and-git.sh


install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/pixmaps/%{name}.xpm"
%suse_update_desktop_file %{buildroot}/%{_datadir}/applications/%{name}.desktop
#This is a man page made by help2man to satisfy factories hunger for one /usr/bin/ one man page.
mkdir -p %{buildroot}%{_mandir}/man1
install -D -m 0644 "%{SOURCE2}" "%{buildroot}%{_mandir}/man1/"
%fdupes -s %{buildroot}%{_datadir}/

%post
/usr/bin/update-mime-database "%{_datadir}/mime" >/dev/null

%postun
/usr/bin/update-mime-database "%{_datadir}/mime" >/dev/null

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README
%dir %{_datadir}/appdata
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/autoload
%dir %{_datadir}/%{name}/chords
%dir %{_datadir}/%{name}/examples
%dir %{_datadir}/%{name}/fonts
%dir %{_datadir}/%{name}/library
%dir %{_datadir}/%{name}/locale
%dir %{_datadir}/%{name}/profile
%dir %{_datadir}/%{name}/scripts
%dir %{_datadir}/%{name}/styles
%dir %{_datadir}/%{name}/templates
%dir %{_datadir}/%{name}/templates
%{_datadir}/icons/hicolor/*
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_mandir}/man1/*
%{_datadir}/%{name}/*
%{_datadir}/%{name}/presets/*
%{_datadir}/%{name}/pixmaps/*
%{_datadir}/%{name}/autoload/*
%{_datadir}/%{name}/chords/*
%{_datadir}/%{name}/examples/*
%{_datadir}/%{name}/fonts/*
%{_datadir}/%{name}/library/*
%{_datadir}/%{name}/locale/*
%{_datadir}/%{name}/profile/*
%{_datadir}/%{name}/scripts/*
%{_datadir}/%{name}/styles/*
%{_datadir}/%{name}/templates/*
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/appdata/rosegarden.appdata.xml

%changelog
* Sun Oct 16 2016 davejplater@gmail.com
- Added rosegarden-fix-crash.patch to fix rosegarden bug:
  https://sourceforge.net/p/rosegarden/bugs/1536/
* Wed Jul 20 2016 davejplater@gmail.com
- Update to release 16.06, codename "Rhapsody in Blue".
- Removed rosegarden-16.02-gcc6.patch, fixed in this version.
- Refreshed rosegarden-10.10-filepaths.patch
- Upstream changes:
  * Bug Fixes
    Avoid deleting softsynths when importing banks
    Avoid drawing segment note previews outside the segment
    borders (#1513).
    Avoid edit views stealing focus from main window in Qt5 (#1508)
    Hide splash screen if still visible when showing file load
    errors.
    Constrain transpose to the usable 0-127 pitch range (#1415).
    The “Accidentals in one bar…” preference is now considered for
    previewing accidentals when inserting notes in notation editor.
    Fix color of cautionary accidental in preview or selection.
    Improve the split and tie long notes at bar lines function to
    cover certain edge cases (#1517).
    Avoid changing stem direction in the middle of a beaming group
    in on-screen rendering or LilyPond export.
    Lilypond export: respect beams for grace notes too. They were
    incorrectly understood as a chord, because they are all at the
    same absolute time.
    Fix undesired channel cleaning at start of second segment
    (#1516).
    AudioPluginManager: Fix broken plugins
    Keep plugins dialog from growing unnecessarily
    Fix selecting legato type would skip to notation on relaunch
    on quantize parameters.
    Fix add articulations wouldn't restore on relaunch in grid
    mode only on quantize parameters.
    Fix channel setup conflicts when daisy chaining
  * New Features
    Lock files so only one Rosegarden instance can edit a particular
    file at any one time.
    New Layer From Selection function to make it easier to resolve
    overlapping polyphonic voices by hand (this function does not
    undo cleanly).
    Multi-track solo mode.
    Archive mode.
* Tue Jun 21 2016 davejplater@gmail.com
- Added upstream rosegarden-16.02-gcc6.patch to fix gcc6 build see
  boo#985242
* Mon Mar 21 2016 davejplater@gmail.com
- Added requires and reccomends for packages needed by rosegarden.
* Sun Mar 20 2016 davejplater@gmail.com
- Enable QT5 build for openSUSE:Leap:42.1
- Remove obsolete Provides for old rosegarden4 and rosegarden-qt4
* Sat Mar 19 2016 crrodriguez@opensuse.org
- make the QT5 switch only In Tumbleweed and future products.
* Fri Mar 18 2016 crrodriguez@opensuse.org
- Build against QT5 in openSUSE 13.2 or later
- Only provide rosegarden-qt4 in old products with QT4.
* Thu Mar  3 2016 davejplater@gmail.com
- Update to version 16.02 codenamed "Querida"
- Now uses cmake to build, adjusted spec file.
- Upstream changes and bug fixes:
  * Bug Fixes
    Fix #1486,involving interacting with the loaded document while
    in the middle of loading a new one.
    Fix scroll bar refresh problem after adding segments.
    Make it possible to disable LIRC, even when it's detected.
    Correct the install location of data files on some platforms
    Fix scrollbar problem after inserting segments
    Fix handling of segment labels when copying/pasting segments
    Reduce number of undo/redo events on the stack for some user
    actions (one action one undo instead of one action two or more
    undos).
    Various tweaking and twiddling of tooltips, context sensitive
    help, and layout spacing.
    Fix notation editor context menu (#1492)
    Fix notation editor crash on double middle click (#1493)
    Fix label issue with drag copy undo. Bug #1450. Undo after
    ctrl+drag copy now restores the proper label to the original
    segment.
    Fix Insert Controller Sequence (Bug #1478) Previously, in the
    NotationView, adding a controller sequence where there were no
    matching controller sequences would reset the start time of the
    segment to 0. Now it leaves the segment start time alone.
    Fix #1478: Segments extended to the beginning after adding
    controller sequence.
    Fix refresh bug introduced by r14441
    At file load time, only a single set of CCs goes out (#1480)
    Add “Allow Reset All Controllers” to preferences. This fixes
    bug #1485 and is related to bug #1480.
    Fix #1504.THRU routing responds to Track Parameters changes
    instantly.
  * New Features
    Add the capability to store any number of comments pages in the
    composition. This allow the translation of the notes displayed
    in a popup dialog when the document is loaded.
    The comment page whose name matches the locale language code is
    displayed.
    Add a French translation to the comment embedded in
    lilypond-alternative-endings_new-way.rg example file.
    When using the mouse to enter notation, you see a preview of
    the note that you will enter if you click the button.
    New mouse quick entry mode:
    The mouse wheel can be used to select the note or rest
    duration.
    A mouse mid click switches between note and rest insert mode
    Holding the Shift key while entering a note adds a sharp
    Holding the Control key while entering a note adds a flat
    Holding Shift + Ctrl while entering a note adds a natural
    Implement track-by-track THRU routing. The Recording filters
    “Thru Routing” field in the Track Parameters box is now fully
    functional.
    The Studio → MIDI Through Routing menu option has been removed.
* Tue Dec 15 2015 davejplater@gmail.com
- Update to version 15.10.2 and refresh patches.
- Upstream changes see http://rosegardenmusic.com/wiki/dev:15.10
* Sat Aug 29 2015 tom.mbrt@googlemail.com
- Update to 14.12:
  + Bug Fixes:
  - Fix translation bug #1423 via patch from Stuart
    Prescott; update all translations. (r13665)
  - Position pointer now moves to the end of paste to
    allow repeated pasting of segments. (r13667)
  - Fix recording of zero-length events (Bug #1365, r13672)
  - Add MuPDF and ePDFView to supported PDF viewers
    (Thomas Kaeding, r13673)
  - Disable destructive actions in playback/record
    (Bug #837, r13676)
  - Numerous fixes to opening http and ftp URLs bydrag/drop.
    With help from Tim Munro. (r13704, r13705, r13706, r13712)
  - Several Qt5 related patches from Tim Munro.
  - Set note-off velocity to 64 as recommended by the MIDI
    spec. (Bug #1426, r13710)
  - Set default volume to 100 in rgd files (r13794)
  - Add support for and prefer xdg-open for opening PDF files
  + New Features:
  - You can enter text dynamics from “d05” to “d125” counting
    by 5 to get these velocities interpreted directly as written
    (Fernando Martin, r13666)
* Sat Nov 29 2014 Led <ledest@gmail.com>
- fix bashisms in scripts
- add patches:
  * rosegarden-14.02-fix-bashisms.patch
* Fri Sep 19 2014 davejplater@gmail.com
- Update to release 14.02 code named "Kaleidoscope"
- Upstream Bug Fixes
  * Fix a transposition bug (Bug #1383, r13540).
  * Fix a bug related to running status and meta events in exported MIDI files
    (r13544)
  * Fix an endless loop with certain MIDI files (Bug #1419, r13550)
  * Pitch tracker patch from Nick Bailey (r13597)
  * Fix a crash when exporting to LilyPond with an empty copyright header
    (r13603)
  * Fix for bad handling of "(c)" in the copyright header when exporting to
    LilyPond (r13603)
  * Fix for handling obscure MIDI files that have an extra unused padding byte
    at the very end (r13604)
  * Fix to allow controllers in zero-length segments to play (r13650)
  * Fix for guessBeats crashes (r13653)
  * Fix for channel allocator waste-minimizer (r13654)
  * Fix to avoid freeing zero-length intervals (r13655)
  * Fix Jump to Quick Marker shortcut, Ctrl+M, in notation (r13656)
  * Fix for first note of a segment playing late (Bug 1378, r13657)
- New Features
  * New auto-expand feature added to the Change Composition Length dialog
    (Feature #417, r13542, r13555).
- New Device Files
  * Casio CTK-3200 device file contributed by Eric (tuxyme)
* Sun Dec 22 2013 zaitor@opensuse.org
- Update to version 13.10:
  + Bugs Fixed:
  - Pitch Bend Sequence Dialog, number of steps must be positive.
  - Fix disconnected move up staff / move down staff commands.
  - Fix sysex import dialog black-on-black problem.
  - Fix for #1372 Rests of new segments don't adapt to time
    signature changes.
  - Fix a refresh bug introduced in r13273 and present in 13.06
    involving deleting contemporaneous segments on a track. This
    may have broken CompositionView refresh in other cases as
    well.
  - Fix UTF8 in track and segment names.
  - Fix the update of notation editors when a track name is
    changed.
  - Fix a "No such key" bug in the key signature dialog.
  - Fix MIDI thru latency issue when recording.
  - Fix repeating segments so they function when overlapping on
    one track.
  - Fix tuplet numbers drawing in black when they should be other
    colors.
  - Fix several interconnected bugs related to MIDI export that
    were causing a variety of problems due to issues with bad
    event ordering and the introduction of spurious controllers.
  - Fix problems when recording past the end of the composition.
  - Fix various crashes when pasting.
  - Fix crash when attempting to import programs from .sfArk
    files (format not supported).
  + New Features:
  - Selection event filter can select rests.
  - Selection event filter can select either performance or
    notation duration.
  - LilyPond export converts a ''(c)'' or a ''(C)'' in the
    copyright header to a proper symbol automatically.
  - New interpretation toolbar for the notation editor
    streamlines the ''**Adjust -> Interpret**'' process.
  - New option to allow LilyPond to export fingerings inside the
    staff (can improve collision resolution).
  - New option to instruct Rosegarden not to start JACK
    automatically at startup, allowing you to control this
    behavior without having to put garbage in your ~/.jackdrc
    file.
  - Support LilyPond 2.14.
  - Added a appdata file.
- Changes from version 13.06:
  + Bugs Fixed:
  - Fix disappearing ties in notation editor.
  - Program changes are now sent on channels for tracks that are
    armed when going into record.
  - CPU usage reduced by almost 50%% when recording MIDI.
  - The range editing commands no longer mess up markers.
  - Fixed an internal leak in the channel allocator.
  - Fixed a crash on paste bug, while revealing other related
    problems that remain to be fixed.
  - Fixed latency compensation in subgroups through a mysterious
    mechanism that seems to work.
  - Fixed a subtle bug involving the drawing of track dividers
    and vertical scrolling.
  - Changing note durations works correctly across barlines. So
    does adding dots to notes.
  - Menu items have a somewhat more consistent style.
  - Certain crashes related to Paste commands shouldn't happen
    any more.
  - The tempo dialog now defaults more sensibly to replacing the
    most recent tempo.
  - Now when you change staffs in the notation editor (with Next
    Staff Down, etc) Rosegarden chooses the next staff more
    sensibly.
  - When you open multiple segments in the notation editor,
    Rosegarden chooses a starting staff more sensibly.
  - Range commands such as edit -> Cut Range now don't split
    segments. Previously only Insert Range kept segments intact.
  - Range commands also try to keep linked segments linked
    together when possible.
  + New Features:
  - Additional work and improvements on the pitchbend sequence
    dialog.
  - Controllers are now easier to place and arrange thru the
    Notation -> Adjust -> controllers -> Insert Controller
    Sequence... menu. The dialog isn't new but it is clearer than
    before and gives you more control over what is placed.
  - "Move to Staff Above" and "Move to Staff Below" now have
    variants that ask what type of pasting to do; formerly it was
    always notation-style pasting.
  - It is now easier to create beat tracks, ie tracks that have a
    note on each beat for use with FitToBeatsCommand and/or
    groove quantize. See [[how_to_make_beat_tracks]].
  - For those users (both of you) who use Segment -> Expand Block
    Chord Segments by Figuration, there is now support for
    figurations without parameter chords.
  - Also for those who use Segment -> Expand Block Chord Segments
    by Figuration, there is Segment -> Update all Figurations,
    which tracks down all regions previously generated from
    figurations and updates them.
  - Ornaments can now be [[how_to_edit_ornaments|inspected and
    edited]] inline, as notation.  Formerly they were only
    available in the Event List Editor.
  - If you want to try to use Rosegarden as a true layered
    editor, ornaments whose trigger consists of tied notes can
    even be set so that only certain sections play.
  - Range commands and other commands that move segments timewise
    are faster now.
* Sun Apr 28 2013 davejplater@gmail.com
- Update to release 13.04 code named "Allysand"
- Upstream bug fixes :
  * Don't export certain properties in MusicXML that MusicXML can't
    handle
  * Fix #1387; export text events (eg. lyrics) to MIDI
  * Fix #703; auto-beaming no longer does an extra unselected bar
  * Fix minor notation layout issue
  * Fix notation scrolling problem
  * Fix bug with FreeChannel
- New features :
  * Choose among 0db, -3dB, -6dB panning laws for audio
* Wed Feb  6 2013 davejplater@gmail.com
- Update to release 12.12.25
- Removed patches rosegarden-10.02-plugin-lib64path.patch,
  rosegarden-gcc47.patch and rosegarden-11.11-gplv2+.patch
  now incorporated upstream.
* Sat Mar 24 2012 dimstar@opensuse.org
- Add rosegarden-gcc47.patch: Fix build with gcc 4.7.
* Wed Mar  7 2012 davejplater@gmail.com
- Fixed Wrong license statement in "About box" and incorect FSF
  address in COPYING with rosegarden-11.11-gplv2+.patch meanwhile
  patch submitted upstream.
* Thu Jan 26 2012 davejplater@gmail.com
- Update to version 11.11.42 as requested.
- For changes visit :
  http://sourceforge.net/projects/rosegarden/files/rosegarden/11.11/
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Dec  1 2011 coolo@suse.com
- set _service to localonly to be acceptable for factory
* Thu May 19 2011 davejplater@gmail.com
- Update to version 11.06, codename "Don Juan".
- Upstream bug Fixes: *A commonly-used time entry widget has had
  it's functionality improved and some usability problems solved.
  * Fixed undo after copying/pasting a range.
  * When adding marks to a selection that includes a mixture of notes
  and rests, avoid applying meaningless marks to the rests.
  * Insert Range now preserves the loop/range.
  * Fixed a LilyPond export bug that caused problems with human
  performances where the notes had a physical start time preceding
  the bar line significantly.
- New features: *the Glasgow Pitch Tracker fork finally merges
  into the new codebase,
  * Expose the instrument alias to external plugin GUIs making
  plugins easier to identify in applications like FLAM.
  * Export LilyPond code using any of LilyPond's supported languages.
* Mon Apr  4 2011 davejplater@gmail.com
- Update to 11.04.12272 Fixes bnc#579168
- For upstrea fixes see :
  /usr/share/doc/rosegarden/CHANGES.txt
* Fri Feb  4 2011 davejplater@gmail.com
- Update to version 11.02, rosegarden-gcc46fix.patch is merged.
- Upstream bug Fixes: *Track numbers are no longer cut off
  * The notation and matrix editors now treat a series of tied
  notes as though it were a single unit, which fixes several
  problems that have been outstanding since as far back as 2002
  * Resizing a segment via click and drag near the edge or with the
  resize tool now leaves that segment as the selected segment
  * When attempting to select a note by clicking toward the extreme
  edges of the note head, it is less likely that you will move the
  note instead of merely selecting it.
  * Insertion / Playback pointer correctly advances in Notation
  editor when entered notes are split and tied.
  * Progress dialogs tweaked to fine tune their behavior.
  * Alt+PgUp and Alt+PgDown now highlight the events in a segment in
  Notation view consistently.
- New Features: *The matrix editor represents tied notes with a
  different fill pattern
  * The split-and-tie long notes option has been made the factory
  default once more, in light of the vastly improved handling of
  ties in the matrix and notation editors.
- Translations complete and uptodate: Spanish French German
- Missing less than 50 translations: Czech (česky)
- Missing less than 100 translations: Japanese Swedish Finnish
- Missing less than 500 translations: Chinese Italian
- Missing more than 1000 translations: Russian Dutch
- Missing more than 2000 translations: Indonesian
- Missing more than 4000 translations: Catalan Welsh Estonian, Basque Polish
* Sat Dec  4 2010 davejplater@gmail.com
- Update to svn snapshot 10.10.12152
- Upstream changes :
  * Italian update by Mario Moles
  * Czech update by Pavel Fric
  * Resizing a segment via click and drag near the edge or with the
  resize tool now leaves that segment as the selected segment.
  * Fixed the grace note bug.
* Wed Nov 24 2010 davejplater@gmail.com
- Update to svn snapshot 10.10.12147
- Upstream changes :
  * ifdef around code that only works in Qt 4.6+
* Tue Nov 23 2010 davejplater@gmail.com
- Update to svn snapshot 10.10.12146
- Added CHANGES.txt and various other text docs
- Upstream changes :
  * fix #3114498
  * patch from J. P. Morris in connection with #3109133
  * Also removing the deprecated constructor in LineEdit
  * Modified the InsertTupletDialog to have SpinBoxes, and also the
  tuplet.png
  * Correct some comments
  * Some layout fixes to TupletDialog and InsertTupletDialog; remove
  redundant includes correct "Insert rest" to "Insert Rest"
  * Adding an insertion mode for general tuplets
  * nice little triplet time beaming incremental improvement from
  Colin Fletcher
  * Holding down Ctrl while dragging in the loop ruler now causes the
  playback position pointer to snap to beat.
  * Enable QGraphicsView::IndirectPainting mode on Panner.
  * Single sweep selecitons are working now.
  * Skip indications in spilt-by-pitch.
  * More work on handling ties in the matrix.
  * A fixed point size of 7 is the number here.My track numbers no
  longer have the top third cut off.
  * Prep for 11.02, I'm guessing.  10.12 might be possible.  We'll go
  with "Claire de Lune" for this one.  "Don Juan" proposed for the
  next one, simply because I used to have a Don Juan rose.  It's a
  good classic red climber.
  * I also fixed a stylesheet issue that I'm not bothering to
  propagate to the stable 10_10 branch.
* Fri Nov  5 2010 davejplater@gmail.com
- Added man page generated by help2man
* Thu Nov  4 2010 davejplater@gmail.com
- Update to release 10.10 and renamed to rosegarden
- Upstream changes :
  * Many fixes to track program/bank behaviour change, save/load and percussion check-box (Julie Swango)
  * Allow shift-click on a track header to toggle segment selection on track without affecting segments (Yves Guillemot)
  * Improve key highlights in matrix view to reflect current segment properly (Julie)
  * Add support for basic LADISH level 1 (Felipe Lopes)
  * Fixed a number of problems with the wrong audio clip being played (Julie)
  * Fix crash when opening file dialog not in  default Thorn style (Chris Cannam and D. Michael McIntyre)
  * Fix incorrect behaviour of frequency-range parameters in LADSPA and DSSI plugin editors (Chris)
  * Fixes to missing-audio-file location logic (Chris)
  * Shorten factory autoload, removing lower sets of tracks all tracks visible (Michael)
  * Fix MIDI recording from devices with note-on and note-off not clean paired (Julie)
  * Fixes to positioning of playback pointer in matrix (Julie)
  * Several large fixes to step-recording in matrix & notation (Julie)
  * Several fixes to Lilypond export (Julie)
  * Many fixes to segment editor to prevent zero-length segments (Ted Felix)
  * Many fixes to prevent zero-length events or ranges (Ted)
  * Fixes to unpredictable behaviour in operations copying segments (Ted)
  * Many fixes to editing operations to stop segment overlap with end of composition (Julie and Ted)
  * Make behaviour of Paste Range more predictable (Ted)
  * Improve chord database and many fixes to fretboard editor (Ted)
  * Fixes to avoid zero-duration note events in files (Michael and Julie)
  * Fixes to toolbar visibility in editing views (Julie)
  * Fixes to regressions in action availability (Ian Gardner)
  * Fixes to updates in notation view (Yves and Julie), event list
  editor (Julie), matrix editor (Julie) and rulers (Julie and Alvar Udras)
  * Restore progress dialogs (Julie)
* Mon Oct 25 2010 davejplater@gmail.com
- Update to svn 12103
- Upstream changes :
  * remove obsolete Japanese translations
  * German update
  * Japanese update...
  * Coding standards.
  * Enormous Chinese update from Rui Fan
* Fri Oct 15 2010 davejplater@gmail.com
- Update to svn 12093
- Upstream changes :
  * Fixed a crash.  Cut an audio segment, delete the underlying
  audio file from the audio file mgr, then paste the audio segment back in.
  * Overhaul encoding selector dialog (used when importing MIDI files
  with non-ASCII text in them).
  * Fixed a crash when pasting audio segments from a previous document.
  * Converted tabs to spaces in Clipboard.cpp.
  * ChordMap no longer writes out corrupt chords.xml files.
* Fri Oct  8 2010 davejplater@gmail.com
- Update to svn 12089
- Upstream changes :
  Update tutorials menu link
  Fixed rescale MIDI segments from the left bug
  patch from Alvar Udras 'notation edit page jumps to right too much' fix
  Resized segments remember their size even when truncated at composition end.
  The ChordMap's "m_needSave" flag is now cleared immediately after
  chords.xml is read to prevent unnecessarily writing the unchanged file
  out.  This avoids a bug in ChordMap::saveDocument() which causes the
  user's local chords.xml file to become corrupt
  ChordMap no longer writes out corrupt chords.xml files.
* Thu Apr 29 2010 davejplater@gmail.com
- Update to 10.04 bugfix release 2.
- Fixes bnc#595479, bnc#574943, bnc#586083 and bnc#599517
- Disabled debug messages
- Upstream fixes :-
  * Fix crash when importing studio from a document that has more MIDI
  devices than the current document
  * Fix crash when inserting a breve at the start of a two-bar 4/4 segment
  * Fix crash when changing synth or plugin settings in a window other
  than the main window, when no synth or audio instrument is assigned in
  the current document but one had been assigned in the previously
  loaded document (#2954068)
  * Fix failure to add tempo changes when asked to do so from the menu,
  in matrix and notation
  * Fix problems mapping international file names to local encoding
  * Fix crash when cancelling file dialogs in some circumstances
  * Fix failure to compile with Qt 4.7
* Sun Apr 25 2010 davejplater@gmail.com
- Update to 10.04 release, removed rosegarden4rpmlintrc and clean up
  spec file.
- Fixes bnc#571481
- This is a bug fix release :-
  * Fixes to crashes and incorrect updating in the notation editor
  * Restore duration-change shortcuts in notation forgotten in 10.02
  * Various small efficiency improvements
  * Fixes to LIRC support
  * Fixed to configure process to permit user override of CXXFLAGS
    and improve platform compatibility
  * Minor improvements to desktop file definition
* Sun Apr 11 2010 davejplater@gmail.com
- Update to rosegarden-10.04, removed patches due to upstream fix :-
  rosegarden-10.02-desktop.patch, rosegarden-10.02-rpmoptflags.patch
  Updated patch rosegarden-10.02-filepaths.patch to
  rosegarden-10.04-filepaths.patch due to source changes.
- Now at svn revision 11865 snapshot.
* Mon Apr  5 2010 davejplater@gmail.com
- Fixed examples, templates and library file paths with
  rosegarden-10.02-filepaths.patch
* Thu Apr  1 2010 davejplater@gmail.com
- Added requires lilypond for 11.3 and requires ladspa
* Sat Feb 20 2010 davejplater@gmail.com
- Cleaned up spec file
* Wed Feb 17 2010 davejplater@gmail.com
- Removed rosegarden wrapper script as it's no longer needed.
* Wed Feb 17 2010 davejplater@gmail.com
- Update to Rosegarden-10.02 release
- Fixes bnc#571474, bnc#571478, bnc#580355, bnc#568658 and
  bnc#566826.
- Rosegarden 10.02 is a complete rewrite and has evolved from a kde3
  application to a stand alone qt4 based application.
  See http://www.rosegardenmusic.com/wiki/dev:10.02 for a full list
  of new features and enhancments.
* Mon Feb 15 2010 davejplater@gmail.com
- Update to svn revision 11820
* Wed Jan 27 2010 davejplater@gmail.com
- Submitted rosegarden-10.02-plugin-lib64path.patch upstream
* Thu Jan 21 2010 davejplater@gmail.com
-Update to svn rev 11681 fix ladspa and dssi plugin search paths with
  rosegarden-10.02-plugin-lib64path.patch
* Wed Jan  6 2010 davejplater@gmail.com
-Update to svn rev 11575 Fix bnc#566826, bnc#564322 and bnc#567555
* Tue Dec 29 2009 davejplater@gmail.com
-Removed rosegarden-10.02-mime-stop.patch due to upstream fix.
* Mon Dec 28 2009 davejplater@gmail.com
-Update to Svn Rev 11521 Save toolbar settings added.
* Sun Dec 27 2009 davejplater@gmail.com
-Created rosegarden-10.02-mime-stop.patch to stop update-mime-database from
  being run by make install
* Fri Dec 25 2009 davejplater@gmail.com
-Update to svn Rev 11509 Rosegarden-qt4 now in the beta stage
  Fixes bnc#549850, bnc#549870, bnc#551644 bnc#551669 and bnc#564295
* Mon Nov  2 2009 davejplater@gmail.com
-Created workaround wrapper script for bnc#549870
-Update to svn revision 11155
* Sat Oct 31 2009 davejplater@gmail.com
-Update to svn revision 11152 to fix bnc#549870
* Tue Oct 20 2009 davejplater@gmail.com
-Update to svn revision 11066
-Added x-rosegarden.desktop and rosegarden.xpm
* Sun Oct 18 2009 davejplater@gmail.com
-Removed rosegarden-mathmeaning.patch due to it's incorporation upsteam
  Now svn revision 11058
* Sun Oct 18 2009 davejplater@gmail.com
-checked in svn revision 11056
* Fri Oct 16 2009 davejplater@gmail.com
-Fixed mathmeaning error with rosegarden-mathmeaning.patch
* Sat Oct 10 2009 davejplater@gmail.com
- packaged rosegarden-qt4 version 10.02 using the buildservice spec file wizard
* Fri Jul 24 2009 tiwai@suse.de
- fix buildrequires: dssi -> dssi-devel
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Feb 18 2009 tiwai@suse.de
- updated to version 1.7.3:
  * bug fix / maintenance release.  See the URL below for details
    http://www.rosegardenmusic.com/wiki/dev:1.7.3
- remove kdemultimedia3-sound from buildrequires (which was
  dropped from FACTORY).
* Mon Jan 19 2009 tiwai@suse.de
- updated to version 1.7.1:
  * Improve resilience of frame - realtime - frame round-trip
    conversions
  * Make it possible to use synth plugins for the metronome
  * Use the name of the segment in the clipboard as the default
  label when adding a new triggered segment via the triggered
  segments manager
  * It is now possible to configure Rosegarden so that it no longer
  appends strings like ”(copied)” and ”(split)” to segments when
  manipulating them
  * Indonesian translation
  * Fix crash when cutting a range
  * Export either fractional or common time signatures to match the
  notation editor, with some minor constraints imposed by
  LilyPond
  * Implement ottava brackets in LilyPond export
  * Export pedal marks as \sustainDown and \sustainUp in LilyPond
  * Distinguish between 8va/8vb and 15ma/15mb a la LilyPond
- updated to version 1.7.2:
  * maintenance release
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 1.7.0:
  * Check headers in Notation view
  * Test to see if a newer version is available
  * New Welcome dialog
  * Notation: The preferred stem direction in a chord around the
    middle line is down
  * Notation: The preferred beam position in a beamed group around
    the middle is below
  * Add icons for Add tempo and Add time signature
  * Move to Staff Above or Staff Below
  * Radically reformed grace notes now work correctly
  * Sync segments to track parameters
  * "Convert notation for..." function added
  * Expanded/corrected instrument presets database
  * Export markers to LilyPond
  * Alternative shortcut for Play/Stop in laptop use: Ctrl+Return
  * New track parameters for exporting square, curly, and nested
    brackets to LilyPond
  * The transport mode setting is now stored with and restored
    from individual compositions
  * Export the new radically reformed grace notes into LilyPond
    syntax
  * Now ties can finally be flipped
  * Arbitrary dynamics exported to LilyPond as markups if they
    are not on LilyPond's list of supported dynamic types
  * Manually repositioned rests (as when rearranging badly
    rendered overlapping voices) are now exported to LilyPond
  * Set a quick playback position marker in the main window with
    Ctrl+1 and recall it with 1
  * New variable height tracks finally make working with
    overlapping segments
  * Smarter selections in matrix and notation views now allow you
    to remove individual, previously-selected events without
    beginning the entire selection process from scratch
* Fri Jan 11 2008 tiwai@suse.de
- updated to version 1.6.1:
  * fixed tempo changes saving
  * fixed the handling of logarithmic control parameters for
    LADSPA and DSSI plugins
* Mon Dec 17 2007 tiwai@suse.de
- updated to version 1.6.0:
  * Diatonic transpose
  * Fretboards
  * Marker ruler usability improvements
  * Multiple lines of lyrics
  * Highlight overlapping notes in notation editor
  * Better LilyPond output dialog, preview through Lilypond,
    print through LilyPond from segment and notation views
  * In-place LilyPond header value editing in LilyPond option dialog
  * Transposition of the staff shown in LilyPond output
  * Show current segment colour in raw note ruler, permit cycling
    through segments on single staff in notation
  * Menus and configuration dialog reorganised for easier access and
    greater clarity
  * Infrared remote control: Support for IRKick
  * Add track(s) in middle
  * Use RTC timer when recent kernel and ALSA versions are detected
  * Expanded documentation
  * Reorganised configuration dialog into standard/advanced options
  * Some revised example files
  * Nice new splash screen
* Wed Nov  7 2007 tiwai@suse.de
- fix build with gcc 4.3.
* Mon Sep  3 2007 schwab@suse.de
- Fix broken compiler flags.
- Fix undefined operation.
* Mon Aug  6 2007 tiwai@suse.de
- add requirement of libsndfile-progs package (#297511)
* Fri Jun 22 2007 tiwai@suse.de
- fix desktop file to make rpmlint happier
* Wed Jun 20 2007 tiwai@suse.de
- fix fdupes usage
* Wed May 23 2007 tiwai@suse.de
- use fdupes to reduce file size
* Thu May  3 2007 wstephenson@suse.de
- fix buildrequires libraptor1-devel -> libraptor-devel
* Thu May  3 2007 lrupp@suse.de
- fix buildrequires raptor-devel -> libraptor1-devel
* Tue Apr 17 2007 tiwai@suse.de
- fix buildrequires ladspa -> ladspa-devel
* Tue Mar 27 2007 tiwai@suse.de
- updated to version 1.5.1:
  * minor bugfix release
* Wed Feb  7 2007 tiwai@suse.de
- updated to version 1.5.0:
  * Add timestretching for audio segments
  * Add import and sample-rate conversion helper for arbitrary
    audio file types
  * Add helpful context help to status bar in track and matrix
    editors
  * Various improvements to the usability and friendliness of
    the matrix editor
  * Add tempo tapping to tempo dialog
  * Further fixes and enhancements to Lilypond export
  * New Invert, Retrograde, Retrograde Invert editing functions
  * Make transport window remember its previous location
  * More helpful warning dialogs on startup if something fails
    to start properly
  * Change build system from scons to cmake
  * Reorganise code into a new directory structure with a far
    more consistent file naming and organisation scheme
- fixed BuildRequires for cmake
- use own *.desktop to avoid nasty problems with
  %%suse_update_desktop_file and the desktop file checker.
* Tue Jan 16 2007 tiwai@suse.de
- fix compilation with RPM_OPT_FLAGS
- fix x = x++ style bugs
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 1.4.0:
  * Multiple MIDI tracks can be recorded
  * A new track parameter box
  * The composition no longer has a fixed duration
  * Special directives in the notation editor can be used
  * Soprano clef has been added
  * Lilypond export now supports LilyPond 2.8
  * Cut, copy and paste "ranges" within a composition
  * Can split selected segments at an arbitrary time
  * Tempos can now be "ramped"
  * The tempo ruler has been overhauled
  * Can zoom in and out of editing views
  * The Panic function is now accessible
  * Can now respond to MMC/MTC
* Fri May 19 2006 tiwai@suse.de
- updated to rosegarden-4-1.2.3:
  * based on scons instead of auto-tools
  * fix for gcc-4.1
  * MTC support
  * improved backend supports
- fixed spec for scons
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 tiwai@suse.de
- disabled mad support (to be distributable)
* Thu Oct 27 2005 stbinner@suse.de
- fix include hints for compilation with Qt 3.3.5
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed May 25 2005 adrian@suse.de
- some more gcc4 fixes
* Tue Apr 19 2005 tiwai@suse.de
- another fix for gcc-4.0 (64bit arch).
* Fri Apr 15 2005 tiwai@suse.de
- fixed the build with gcc-4.0.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Thu Feb 17 2005 adrian@suse.de
- menu entry moved to xdg dir
* Wed Feb 16 2005 tiwai@suse.de
- updated to version 1.0-final.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 1.0pre1.
* Mon Sep  6 2004 tiwai@suse.de
- updated to version 0.9.9.
* Fri Apr 16 2004 tiwai@suse.de
- updated to version 0.9.7.
- disabled the removal of $RPM_BUILD_ROOT in %%install.
* Thu Apr 15 2004 coolo@suse.de
- build without unsermake
* Sun Feb 22 2004 ro@suse.de
- use TOPSUBDIRS instead of SUBDIRS in top Makefile.am
* Mon Feb 16 2004 tiwai@suse.de
- build as non-root.
* Wed Jan 14 2004 tiwai@suse.de
- updated to version 0.9.6.
* Fri Nov  7 2003 ro@suse.de
- fix compilation
* Mon Sep 15 2003 tiwai@suse.de
- build without the optimization.
- fixed the segfault at double-click.
* Tue Aug 12 2003 adrian@suse.de
- add Categories
* Tue Jun 17 2003 kukuk@suse.de
- Fix usage of %%find_lang
* Thu Jun 12 2003 coolo@suse.de
- use %%find_lang
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 0.9.1.
- remove CVS directories in the documentaions.
* Thu Apr 10 2003 ro@suse.de
- updated admin dir
* Tue Feb 25 2003 aj@suse.de
- Add missing assert include.
* Thu Jan 30 2003 tiwai@suse.de
- initial version: 0.8.5.
